import _colorMixin from 'vue-color/src/mixin/color';
import parseColor from './parse-color';

const colorMixin = Object.assign({}, _colorMixin, {
    data() {
        const val = this.value || this.emptyColor;

        return {
            val: parseColor(val),
            hasChanged: false,
            oldHue: 0
        };
    }
});

// Override computed colors
Object.assign(colorMixin.computed, {
    colors: {
        get() {
            return this.val;
        },
        set(newVal) {
            const format = this.format;
            const lastColor = this.val._color;
            const colors = !newVal || !newVal._color
                ? parseColor(newVal, newVal.oldHue || this.oldHue)
                : newVal;
            const currColor = colors._color;

            if(!lastColor || currColor.toString('hsl') === lastColor.toString('hsl')) {
                this.val = colors;
            }

            if(lastColor && currColor.toString(format) === lastColor.toString(format)) {
                return;
            }

            // Assign default format
            currColor._format = format;

            const ret = this.useRawColor
                ? currColor
                : currColor.toString(format).toUpperCase();

            this.hasChanged = true;
            this.lastValue = ret;

            this.$emit('input', ret);
            this.$emit('change', colors);
        }
    }
});

Object.assign(colorMixin.methods, {
    colorChange(data, oldHue) {
        this.oldHue = this.colors.hsl.h;

        this.colors = parseColor(data, oldHue || this.oldHue);
    }
});

Object.assign(colorMixin.watch, {
    value(newVal) {
        this.val = parseColor(newVal || this.emptyColor, this.oldHue);

        if(newVal !== this.lastValue) {
            this.hasChanged = false;
        }
    }
});

export default colorMixin;
