import { storiesOf } from '@storybook/vue';
// import { Object } from 'es6-shim';

import Button from './button';
import ColorPicker from './color-picker';

const registerComponent = (name = 'Unknow', demosMap = {}) => {
    const story = storiesOf(name, module);

    Object.keys(demosMap).forEach(name => {
        story.add(name, demosMap[name]);
    });
};

// Button
registerComponent('Button', {
    'Basic usage': () => {
        return {
            components: { Button },
            template: '<Button/>'
        };
    }
});

// ColorPicker
registerComponent('ColorPicker', {
    'Basic usage': () => {
        return {
            components: { ColorPicker },
            template: `<div style="padding:40px">
                <ColorPicker v-model="color" :enable-input="false" @change="onChange" />
                <p>color: <em :style="{ backgroundColor: color }">{{color}}</em></p>
            </div>`,
            data() {
                return {
                    color: '#080'
                };
            },
            methods: {
                onChange(color) {
                    console.log('change:', color.hex, color);
                }
            }
        };
    },
    'With alpha': () => {
        return {
            components: { ColorPicker },
            template: `<div style="padding:40px">
                <ColorPicker v-model="color" :enable-alpha="true" :format="format" />
                <p>color: <em :style="{ backgroundColor: color }">{{color}}</em></p>
            </div>`,
            data() {
                return {
                    format: 'hex8',
                    color: '#080A'
                };
            }
        };
    },
    'With pattern': () => {
        return {
            components: { ColorPicker },
            template: `<div style="padding:40px">
                <ColorPicker v-model="color" :pattern.sync="pattern" :enable-pattern="true" />
                <p>color: <em :style="{ backgroundColor: color }">{{color}}</em></p>
                <p>pattern: <em>{{JSON.stringify(pattern)}}</em></p>
            </div>`,
            data() {
                return {
                    pattern: null,
                    color: '#080'
                };
            }
        };
    },
    'Use raw color': () => {
        return {
            components: { ColorPicker },
            template: `<div style="padding:40px">
                <ColorPicker v-model="color" :enable-alpha="true" :format="format" :use-raw-color="true" />
                <p>color: <em :style="{ backgroundColor: color }">{{color}}</em></p>
                <p>color.toString: <em :style="{ backgroundColor: color }">{{color.toString()}}</em></p>
            </div>`,
            data() {
                return {
                    format: 'hex8',
                    color: '#080A'
                };
            }
        };
    },
    'With history': () => {
        return {
            components: { ColorPicker },
            template: `<div style="display:flex;padding:40px">
                <ColorPicker v-model="color" />
                <p style="padding: 0 20px;">
                    color: <em :style="{ backgroundColor: color }">{{color}}</em><br>
                    <button @click="togglePickerForHistory()">togglePickerForHistory</button>
                </p>
                <ColorPicker v-model="color" v-if="showXPicker" />
            </div>`,
            data() {
                return {
                    showXPicker: true,
                    color: '#080'
                };
            },
            methods: {
                togglePickerForHistory() {
                    this.showXPicker = !this.showXPicker;
                }
            }
        };
    },
    'Adv usage': () => {
        return {
            components: { ColorPicker },
            template: `<div style="padding:40px">
                <ColorPicker
                    ref="picker"
                    v-model="color"
                    :pattern.sync="pattern"
                    :enable-pattern="true"
                    :enable-alpha="true"
                    @pattern-change="onPatternChange"
                    @change="onChange"
                />
                <p>color: <em :style="{ backgroundColor: color }">{{color}}</em></p>
                <p>pattern: <em>{{JSON.stringify(pattern)}}</em></p>
            </div>`,
            data() {
                return {
                    color: '#080',
                    pattern: null
                };
            },
            methods: {
                onPatternChange(pattern) {
                    console.log('pattern-change:', pattern);
                },
                onChange(color) {
                    // window.x = this;

                    console.log('change:', JSON.stringify(color.hsv), JSON.stringify(color.hsl), color);
                }
            }
        };
    }
});
